#! /usr/bin/python

# Copyright 2013 Jorge Estrada. 
#
# This file is part of azucar.buffer project. 
# It is subject to the license terms in the 
# LICENSE file found in the top-level directory of this distribution. 
# No part of azucar.buffer project, including this file, may be copied,
# modified, propagated, or distributed except according to the terms contained 
# in the LICENSE file.

__version__ = "1.0"

import argparse

import azucar.buffer

def main(args):
    pH = args.pH

    recipe = azucar.buffer.extract_recipe_data_from_file(args.recipe_file)

    if args.chem_types_file:
        buffer_and_species_types = azucar.buffer.setup_buffer_and_species_types(args.chem_types_file)
    else:
        buffer_and_species_types = azucar.buffer.setup_buffer_and_species_types()
    
    solution = azucar.buffer.create_solution_from_recipe(buffer_and_species_types,
                                                         pH,
                                                         recipe)

    print "Ionic strength: %f (Molar)" % solution.get_ionic_strength()

def configureArgumentParser():
  parser = argparse.ArgumentParser(description='Calculate the ionic strength of a solution.',
                                   epilog='Copyright 2013 Jorge Estrada. Apache License version 2.0.')
  parser.add_argument('--version', action='version', version=__version__)
  parser.add_argument('--chem_types_file', help='File name of the chemical species description file. Default: use internal data.')
  parser.add_argument('pH', type=float, help='pH of the solution.')
  parser.add_argument('recipe_file', help='File name with the recipe of the solution.')

  return parser


if __name__ == "__main__":
    parser = configureArgumentParser()
    args = parser.parse_args()

    main(args)
